To perform ODC method and use some transformation to get the initial input for SODC.
Usage
get.hnx.B.initialW(data, k, lambda2)
Arguments
data
A numberic dataset matrix.
k
An integer scalar with the desired number of groups.
lambda2
L2 penalty parameter, if lambda2=-1, then odc.clust choose the optimal lambda2 automatically given lambda2.idx. Otherwise perfoms ODC clustering using given lambda2.
Value
y.initial
The vector derived from the predicted sample scoring matrix Y by ODC.
w.initial
The vector derived from the predicted W by ODC.
what
The predicted W by ODC.
yhat
The predicted sample scoring matrix Y by ODC.
B
A block diagonal matrix with the diagonal component as the normalized Hnx.
hnx
The product of a n by n centering matrix and the input data matrix.